package mi.hdm.recipes;

import java.util.List;
import java.util.Optional;

public class RecipeManager {
    private final List<Recipe> recipes;
    private final Categories categories;
    private final List<Ingredient> ingredients;
    private final NutritionCalculator nutritionCalculator;

    public RecipeManager(List<Recipe> recipes, Categories categories, List<Ingredient> ingredients, NutritionCalculator nutritionCalculator) {
        this.recipes = recipes;
        this.categories = categories;
        this.ingredients = ingredients;
        this.nutritionCalculator = nutritionCalculator;
    }

    public void addRecipe(Recipe recipe){
        recipes.add(recipe);
    }

    public Recipe deleteRecipe(int i) {
        return recipes.remove(i);
    }

    public boolean deleteRecipe(String name) {
        Recipe r = getRecipeByName(name).orElseThrow();
        return recipes.remove(r);
    }

    public RecipeEditor editRecipe (int i) {
        Recipe recipe = recipes.get(i);
        return new RecipeEditor(recipe);
    }

    public RecipeEditor editRecipe (String name) {
        Recipe recipe = getRecipeByName(name).orElseThrow();
        return new RecipeEditor(recipe);
    }

    public RecipeEditor editRecipe(Recipe recipe) {
        return new RecipeEditor(recipe);
    }

    public void addIngredient(Ingredient ingredient) {
        ingredients.add(ingredient);
    }

    public Ingredient deleteIngredient(int i) {
        return ingredients.remove(i);
    }

    public boolean deleteIngredient(String name) {
        Ingredient ingredient = getIngredientByName(name).orElseThrow();
        return ingredients.remove(ingredient);
    }

    private Optional<Recipe> getRecipeByName(String name) {
        for (final Recipe r : recipes) {
            if (name.equals(r.getName())) {
                return Optional.of(r);
            }
        }
        return Optional.empty();
    }
    private Optional<Ingredient> getIngredientByName(String name) {
        for (final Ingredient i: ingredients) {
            if (name.equals(i.getName())) {
                return Optional.of(i);
            }
        }
        return Optional.empty();
    }
}
